@@ -1470,7 +1470,7 @@ nsSVGElement::ParseNumberOptionalNumber(const nsAString& aValue,
   float x = float(PR_strtod(str, &rest));
   float y = x;
 
-  if (str == rest) {
+  if (str == rest || !NS_FloatIsFinite(x)) {
     //first value was illformed
     return NS_ERROR_FAILURE;
   }
@@ -1484,7 +1484,7 @@ nsSVGElement::ParseNumberOptionalNumber(const nsAString& aValue,
     }
 
     y = float(PR_strtod(rest, &rest));
-    if (*rest != '\0') {
+    if (*rest != '\0' || !NS_FloatIsFinite(y)) {
       //second value was illformed or there was trailing content
       return NS_ERROR_FAILURE;
     }
