@@ -40,23 +40,26 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '13.4.4.30.js';
+gTestfile = '13.4.4.20.js';
 
-START("13.4.4.30 - propertyIsEnumerable()");
+START("13.4.4.20 - XML length()");
 
-TEST(1, true, XML.prototype.hasOwnProperty("propertyIsEnumerable"));
+TEST(1, true, XML.prototype.hasOwnProperty("length"));
 
-// All properties accessible by Get are enumerable
 x =
-<alpha>
+<alpha attr1="value1">
     <bravo>one</bravo>
+    <charlie>
+        two
+        three
+        <echo>four</echo>
+    </charlie>
+    <delta />
 </alpha>;
 
-TEST(2, true, x.propertyIsEnumerable("0"));
-TEST(3, true, x.propertyIsEnumerable(0));
-TEST(5, false, x.propertyIsEnumerable("bravo"));
-TEST(6, false, x.propertyIsEnumerable());
-TEST(7, false, x.propertyIsEnumerable(undefined));
-TEST(8, false, x.propertyIsEnumerable(null));
+TEST(2, 1, x.length());
+TEST(3, 1, x.bravo.length());
+TEST(4, 1, x.charlie.length());
+TEST(5, 1, x.delta.length());
 
 END();
\ No newline at end of file
