@@ -35,13 +35,13 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-385393-05.js';
-
+var gTestfile = 'regress-352640-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 385393;
-var summary = 'Regression test for bug 385393';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 352640;
+var summary = 'Do not assert: scopeStmt or crash @ js_LexicalLookup';
+var actual = '';
+var expect = '';
+
 
 //-----------------------------------------------------------------------------
 test();
@@ -53,24 +53,14 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
  
-  function c(gen)
+  try
   {
-    Iterator;    
-
-    "" + gen;
-
-    for (var i in gen())
-      ;
+    new Function("do { with({}) let x; var b; } while( 1 );");
   }
-
-  function gen()
+  catch(ex)
   {
-    ({}).hasOwnProperty();
-    yield;
+    print(ex + '');
   }
-
-  c(gen);
-
   reportCompare(expect, actual, summary);
 
   exitFunc ('test');
