@@ -1233,6 +1233,10 @@ nsListBoxBodyFrame::GetNextItemBox(nsIBox* aBox, PRInt32 aOffset,
       // There is a content node that wants a frame.
       nsIContent *nextContent = parentContent->GetChildAt(i + aOffset + 1);
 
+      if (!nextContent->IsNodeOfType(nsINode::eXUL) ||
+          nextContent->Tag() != nsGkAtoms::listitem)
+        return GetNextItemBox(aBox, ++aOffset, aCreated);
+
       nsPresContext* presContext = PresContext();
       nsIFrame* existingFrame =
         presContext->GetPresShell()->GetPrimaryFrameFor(nextContent);
@@ -1264,6 +1268,9 @@ nsListBoxBodyFrame::GetNextItemBox(nsIBox* aBox, PRInt32 aOffset,
 
   mBottomFrame = result;
 
+  NS_ASSERTION(!result->IsBoxFrame() || result->GetParent() == this,
+               "returning frame that is not in childlist");
+
   return result->IsBoxFrame() ? result : nsnull;
 }
 
